==> enterprisemodules-zfs_appliance-1.2.1.tar.gz: enterprisemodules-zfs_appliance-1.2.1/lib/puppet/type/zfs_appliance.rb <==
#
# See the file "LICENSE" for the full license governing this code.
#
require 'yaml'
require 'easy_type'
$:.unshift("#{File.dirname(__FILE__)}/../..")


module Puppet
  Type.newtype(:zfs_appliance) do
    include EasyType

    SETTINGS_FILE = '/etc/zfs_appliance.yaml'

    desc <<-EOD
      This resource allows you to register ZFS appliance access. Here is an example on how to use this:

          zfs_appliance { 'default':
            password      => 'welcome1',
            verify_ssl    => false,
            appliance_url => 'https://192.168.59.10:215',
          }

      All the other zfs types use this information to connect to the Appliance. You can use this on multiple
      machines.

    EOD

    to_get_raw_resources do
      resources_from_yaml
    end

    parameter :name
    property :username
    property :password
    property :appliance_url
    property :verify_ssl

    def self.configuration
      @configuration
    end

    private

    def self.resources_from_yaml
      Puppet.debug '0 read_from_yaml '
      @configuration = read_from_yaml
      normalize(@configuration)
    end

    def self.config_file
      Pathname.new(SETTINGS_FILE).expand_path
    end

    def self.read_from_yaml
      if File.exist?(config_file)
        open(config_file) { |f| YAML.load(f) }
      else
        {}
      end
    end

    private

    def self.normalize(content)
      normalized_content = []
      content.each do | key, value|
        value[:name] = key
        normalized_content << with_hashified_keys(value)
      end
      normalized_content
    end

    def self.with_hashified_keys(hash)
      result = {}
      hash.each do |key, value|
        result[key.to_sym] = value
      end
      result
    end

  end
end

==> enterprisemodules-zfs_appliance-1.3.0.tar.gz: enterprisemodules-zfs_appliance-1.3.0/lib/puppet/type/zfs_appliance.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
require 'yaml'
require 'easy_type'
$LOAD_PATH.unshift("#{File.dirname(__FILE__)}/../..")
# rubocop:disable Style/Documentation
module Puppet
  # rubocop:enable Style/Documentation
  SETTINGS_FILE = '/etc/zfs_appliance.yaml'
  Type.newtype(:zfs_appliance) do
    include EasyType

    desc <<-DESC
      This resource allows you to register ZFS appliance access. Here is an example on how to use this:

          zfs_appliance { 'default':
            password      => 'welcome1',
            verify_ssl    => false,
            appliance_url => 'https://192.168.59.10:215',
          }

      All the other zfs types use this information to connect to the Appliance. You can use this on multiple
      machines.

    DESC

    to_get_raw_resources do
      resources_from_yaml
    end

    parameter :name
    property :username
    property :password
    property :appliance_url
    property :verify_ssl

    def self.configuration
      @configuration
    end

    def self.resources_from_yaml
      Puppet.debug '0 read_from_yaml '
      @configuration = read_from_yaml
      normalize(@configuration)
    end

    def self.config_file
      Pathname.new(SETTINGS_FILE).expand_path
    end

    def self.read_from_yaml
      if File.exist?(config_file)
        # rubocop:disable Security/Open
        open(config_file) { |f| YAML.safe_load(f) }
        # rubocop:enable Security/Open
      else
        {}
      end
    end

    def self.normalize(content)
      normalized_content = []
      content.each do |key, value|
        value[:name] = key
        normalized_content << with_hashified_keys(value)
      end
      normalized_content
    end

    def self.with_hashified_keys(hash)
      result = {}
      hash.each do |key, value|
        result[key.to_sym] = value
      end
      result
    end
  end
end
